/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.tinytestutil;

import java.util.List;

import org.tinygroup.fileresolver.FileResolver;
import org.tinygroup.fileresolver.FullContextFileRepository;
import org.tinygroup.fileresolver.impl.FileResolverImpl;
import org.tinygroup.fileresolver.impl.FullContextFileFinder;
import org.tinygroup.fileresolver.impl.SpringBeansFileProcessor;
import org.tinygroup.springutil.SpringUtil;
import org.tinygroup.velocity.impl.VelocityHelperImpl;
import org.tinygroup.xmlparser.node.XmlNode;

public abstract class AbstractTestUtil {
	private static FullContextFileRepository repository;
	private static VelocityHelperImpl helper;
	private static final String DEFAULT_FILERESOLVER_BEAN_XML = "/Application.preloadbeans.xml";
	private static boolean  init = false;

	/**
	 * 初始化
	 * 
	 * @param classPathResolve
	 *            是否对classPath进行处理
	 */
	public static void init(String xmlFile, boolean classPathResolve) {
		init(xmlFile, classPathResolve, null, null);
	}
	
	/**
	 * 初始化
	 * 
	 * @param classPathResolve
	 *            是否对classPath进行处理
	 */
	public static void init(String xmlFile, boolean classPathResolve,XmlNode node,List<String> paths) {
		if (init)
			return;
		donInit(xmlFile, classPathResolve,node,paths);
		init = true;
	}

	public static VelocityHelperImpl getVelocityHelper() {
		return helper;
	}

	public static void donInit(String xmlFile, boolean classPathResolve,XmlNode node,List<String> paths) {
		if (xmlFile == null || "".equals(xmlFile))
			xmlFile = DEFAULT_FILERESOLVER_BEAN_XML;
		initSpring(xmlFile);
		FileResolver fileResolver = SpringUtil.getBean("fileResolver");
		if (node != null) {
			repository = SpringUtil.getBean("fullContextFileRepository");
			helper = SpringUtil.getBean("velocityHelper");
			FullContextFileFinder finder = SpringUtil
					.getBean("fullContextFileFinder");
			helper.setFullContextFileRepository(repository);
			finder.setConfiguration(node);
			finder.setFullContextFileRepository(repository);
			fileResolver.addFileProcessor(finder);
		}
		if (paths != null) {
			for (String path : paths) {
				fileResolver.addManualClassPath(path);
				if (repository != null) {
					repository.addSearchPath(path);
				}
			}
		}
		fileResolver.setClassPathResolve(classPathResolve);
		fileResolver.resolve();
	}

	private static void initSpring(String xmlFile) {
		FileResolver fileResolver = new FileResolverImpl();
		fileResolver.addFileProcessor(new SpringBeansFileProcessor());
		fileResolver.setClassPathResolve(true);
		SpringUtil.regSpringConfigXml(xmlFile);
		fileResolver.resolve();
	}

}
